@@ -85,7 +85,7 @@ def log_middleware_async(verbose_exc=False, suppress_exc=False,
                 #Set back original tracer
                 if debug_locals: sys.setprofile(None)
 
-                error_message = str(e)
+                error_message = e.__class__.__name + ': ' + (str(e)) 
 
                 #If exceptions are set to verbose then print the stack trace 
                 if verbose_exc or GLOBAL_VERBOSE:
@@ -195,7 +195,7 @@ def log_middleware(verbose_exc=False, suppress_exc=False,
                 #Set back original tracer
                 if debug_locals: sys.setprofile(None)
 
-                error_message = str(e)
+                error_message = e.__class__.__name + ': ' + (str(e)) 
 
                 #If exceptions are set to verbose then print the stack trace 
                 if verbose_exc or GLOBAL_VERBOSE:
